<?php
/**
 * Theme backward compatibility
 */

/**
 * Prevent switching to theme on WordPress versions prior to 4.5.
 * Switches to the default theme.
 */
function busybella_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'busybella_upgrade_notice' );
}
add_action( 'after_switch_theme', 'busybella_switch_theme' );

/**
 * Message after unsuccessful theme switch attempt.
 */
function busybella_upgrade_notice() {
	$message = sprintf( esc_html__( 'Theme requires at least WordPress version 4.5. You are running version %s. Please upgrade and try again.', 'busybella' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents Customizer loading on WordPress versions prior to 4.5.
 */
function busybella_prevent_customizer_loading() {
	wp_die( sprintf( esc_html__( 'Theme requires at least WordPress version 4.5. You are running version %s. Please upgrade and try again.', 'busybella' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'busybella_prevent_customizer_loading' );

/**
 * Prevents Theme Preview loading on WordPress versions prior to 4.5.
 */
function busybella_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( esc_html__( 'Theme requires at least WordPress version 4.5. You are running version %s. Please upgrade and try again.', 'busybella' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'busybella_preview' );