<?php
/**
 * Theme helper functions
 */

/**
 * Flush rewrite rules for custom post types on theme activation
 */
add_action( 'after_switch_theme', 'busybella_rewrite_rules_flush' );
function busybella_rewrite_rules_flush() {
     flush_rewrite_rules();
}

/**
 * Wrap current page in span for wp_link_pages
 */
if ( ! function_exists( 'busybella_wp_link_pages_wrap' ) ) :
	function busybella_wp_link_pages_wrap( $link ) {
		if ( ctype_digit( $link ) ) {
			return '<span class="page-link-current">' . $link . '</span>';
		}
		return $link;
	}
	add_filter( 'wp_link_pages_link', 'busybella_wp_link_pages_wrap' );
endif;

/**
 * Arrows for menu dropdown
 */
class BUSYBELLA_Dropdown_Walker_Nav_Menu extends Walker_Nav_Menu {
    function busybella_display_element($element, &$children_elements, $max_depth, $depth=0, $args, &$output) {
        $id_field = $this->db_fields['id'];
	     if (!empty($children_elements[$element->$id_field]) && $element->menu_item_parent == 0) { 
            $element->title =  $element->title . '<span class="sf-sub-indicator menu-arrow-down"></span>'; 
			$element->classes[] = 'sf-with-ul';
        }
		if (!empty($children_elements[$element->$id_field]) && $element->menu_item_parent != 0) { 
            $element->title =  $element->title . '<span class="sf-sub-indicator"></span>'; 
        }

        Walker_Nav_Menu::busybella_display_element($element, $children_elements, $max_depth, $depth, $args, $output);
    }
}

/**
 * Responsive - viewport
 */ 
if ( !function_exists('busybella_enable_responsive') ) {
	add_action('wp_head', 'busybella_enable_responsive', 1);
	function busybella_enable_responsive() {
		// Responsive meta viewport
		if ( true == get_theme_mod( 'busybella_enable_responsive', true ) ) {
			echo '<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=0">';
		}
		// Non-responsive meta viewport
		else {
			$width    = intval( get_theme_mod( 'busybella_main_container_width', '1170' ) );
			$width    = $width ? $width: '1170';
			echo '<meta name="viewport" content="width=' . $width . '"/>';
		}
	} 
} 

/**
 * Sanitize checkbox
 */
function busybella_sanitize_checkbox( $input ) {
	if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
} // busybella_sanitize_checkbox

/**
 * Sanitize select
 */
function busybella_sanitize_select( $input, $setting ){
	$input = sanitize_key($input);
	$choices = $setting->manager->get_control( $setting->id )->choices;
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                
}

/**
 * Sanitize textarea
 */
function busybella_textarea_callback ( $value ) {
	return $value;
}

/**
 * Sanitize text field
 */
function busybella_text_callback ( $value ) {
	return $value;
}

/**
 * Thumbnails in Manage Posts / Pages List
 */
if ( ! function_exists( 'busybella_add_thumb_column' ) && function_exists( 'add_theme_support' ) ) { 
	
	// column
	function busybella_add_thumb_column( $columns ) { 
		$columns['thumbnail'] = esc_html__( 'Thumbnail', 'busybella' ); 
		return $columns; 
	} 
	
	// thumbnail
	function busybella_add_thumb( $column_name, $post_id ) { 
		$width = (int) 60; 
		$height = (int) 60; if ( 'thumbnail' == $column_name ) { 
		$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true ); 
		
		if ( $thumbnail_id ){ 
			$thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
		} 

		if ( isset( $thumb ) && $thumb ) { 
			echo wp_kses_post ( $thumb );
		} else { 
			echo '&mdash;';
		} 
	} 
} // busybella_add_thumb_column
// for posts 
add_filter( 'manage_posts_columns', 'busybella_add_thumb_column' ); 
add_action( 'manage_posts_custom_column', 'busybella_add_thumb', 10, 2 ); 
// for pages 
add_filter( 'manage_pages_columns', 'busybella_add_thumb_column' ); 
add_action( 'manage_pages_custom_column', 'busybella_add_thumb', 10, 2 ); 
}