<?php
/**
 * Theme custom paginations
 */

/**
 * Navigation : next/prev for a single post
 */
if ( ! function_exists( 'busybella_post_nav' ) ) :
function busybella_post_nav() {
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );
	if ( ! $next && ! $previous ) {
		return;
	}
	?>
<nav class="dtr-post-navigation dtr-single-post-nav clearfix">
		<?php
	if ( is_attachment() ) :
		previous_post_link( '%link', '<span class="previous-link"><h5>%title</h5></span>' ); else : ?>
		<ul class="dtr-post-nav clearfix">
			<li class="dtr-previous-link">
				<?php previous_post_link( '%link', '<h5> &laquo; %title</h5>' );  ?>
			</li>
			<li class="dtr-next-link">
				<?php next_post_link( '%link', '<h5>%title &raquo;</h5>' ); ?>
			</li>
		</ul>
		<?php endif; ?>
</nav>
<!-- .navigation -->
<?php
}
endif; // busybella_post_nav

/**
 * Navigation : next/prev for set of posts
 */
if ( ! function_exists( 'busybella_archive_nav' ) ) :
function busybella_archive_nav() {
	global $wp_query;
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
<nav class="dtr-post-navigation dtr-archive-nav clearfix">
	<ul class="dtr-post-nav clearfix">
		<?php if ( get_next_posts_link() ) : ?>
		<li>
			<?php next_posts_link( '<span class="dtr-prev"></span>' );  ?>
		</li>
		<?php endif; ?>
		<?php if ( get_previous_posts_link() ) : ?>
		<li>
			<?php previous_posts_link( '<span class="dtr-next"></span>' ); ?>
		</li>
		<?php endif; ?>
	</ul>
</nav>
<!-- .dtr-post-navigation -->
<?php
}
endif; // busybella_archive_nav

/**
 * Pagination : Numbered 
 */
if ( ! function_exists( 'busybella_numbered_pagination' ) ) :
    function busybella_numbered_pagination( $query = '' ) {

        if ( ! $query ) {
            global $wp_query;
            $query = $wp_query;
        }
		
		// vars
		$total  = $query->max_num_pages;
        $big    = 999999999; // unlikely integer

		// pagination
        if ( $total > 1 ) {
		
            // Get permalink structure
            if ( get_option( 'permalink_structure' ) ) {
                if ( is_page() ) {
                    $format = 'page/%#%/';
                } else {
                    $format = '/%#%/';
                }
            } else {
                $format = '&paged=%#%';
            }

            // Get current page
            if ( $current_page = get_query_var( 'paged' ) ) {
                $current_page = $current_page;
            } elseif ( $current_page = get_query_var( 'page' ) ) {
                $current_page = $current_page;
            } else {
                $current_page = 1;
            }

            // Midsize
            $mid_size = '2';
			
            // Pagination output
            $links = paginate_links( array(
                'base'          => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
                'format'        => $format,
                'total'         => $total,
				'current'       => max( 1, $current_page ),
                'mid_size'      => $mid_size,
                'prev_next'          => false,
                'next_text'     => false,
			   'type'               => 'array'
            ) );
			
			if ( $links ) :
	
	 if ( '' == get_previous_posts_link() ) {
		$page_number_style = 'page-numbers-left'; 
	 } elseif ( '' == get_next_posts_link() ) {
	 $page_number_style = 'page-numbers-right'; 
	 } else { $page_number_style = ''; }
	 
    echo '<ul class="dtr-page-numbers clearfix ' . $page_number_style . '">';

    if ( get_previous_posts_link( esc_html__( '', 'busybella' ) ) ) :
        echo '<li class="page-numbers-prev">';
        echo get_previous_posts_link( esc_html__( '', 'busybella' ) );
        echo '</li>';
    endif;

    echo '<li>';
    echo join( '</li><li>', $links );
    echo '</li>';

    if ( get_next_posts_link( __( '', 'busybella' ) ) ) :
        echo '<li class="page-numbers-next">';
        echo get_next_posts_link( __( '', 'busybella' ) );
        echo '</li>';
    endif;
    echo '</ul>';
endif;
        }
    }
endif; // busybella_numbered_pagination