<?php
/**
 * About Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'BUSYBELLA_About_Widget' ) ) {
	class BUSYBELLA_About_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'busybella_about_widget',
      			'description' => esc_html__( 'Display About Information', 'busybella' ),
    		);
    		parent::__construct( 'busybella_about_widget', esc_html__( 'Custom: About', 'busybella' ), $widget_ops );
			add_action( 'load-widgets.php', array( $this, 'admin_setup' ), 100 );
		}
		
		/**
		 * Enqueue media scripts
		 */
		public function admin_setup() {
			wp_enqueue_media();
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 		= '';
			$title      	= isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
			$name   		= empty( $instance['name'] ) ? '' : $instance['name'];
			$job   			= empty( $instance['job'] ) ? '' : $instance['job'];
			$description	= isset( $instance['description'] ) ? $instance['description'] : '';
			$wpautop     	= isset( $instance['wpautop'] ) ? $instance['wpautop'] : '';
			$style			= isset( $instance['style'] ) ? $instance['style'] : 'dtr-about-widget-circle';
			$textalign      = isset( $instance['textalign'] ) ? $instance['textalign'] : 'text-center';
			$image       	= isset( $instance['image'] ) ? esc_url( $instance['image'] ) : '';
		
			// Before widget
			echo $args['before_widget'];
			
			// Widget title
			if ( ! empty( $title ) ) {
				echo $args['before_title'] . $title . $args['after_title'];
			} ?>

			<div class="dtr-about-widget <?php echo esc_attr( $style ) ?> <?php echo esc_attr( $textalign ) ?> clearfix">

			<?php 	// image
			if ( $image ) : ?>
				<div class="dtr-about-widget-img">
					<img src="<?php echo esc_url ( $image ) ?>" alt="<?php echo esc_attr( $title ) ?>"/>
				</div>
			<?php  endif; ?>
			
			<?php
			// name and jon name
			if ( $name != '' || $job != '' ) { ?>
			<div class="dtr-about-header">
			<h5 class="dtr-about-title"><?php echo wp_kses_post( $name ) ?></h5> 
			<span class="dtr-about-subtitle"><?php echo wp_kses_post( $job ) ?></span>
			</div>
			<?php } ?>

			<div class="dtr-about-widget-desc">
			<?php if ( 'on' == $wpautop ) { 
					echo  wpautop( wp_kses_post( $description ) );
				} else {
					echo wp_kses_post( $description );
				} ?>
			</div>
				
			</div>
			<?php
			echo $args['after_widget']; 
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance                 	= $old_instance;
			$instance['title']      	= strip_tags( $new_instance['title'] );
			$instance['name']  			= isset( $new_instance['name'] ) ? trim( strip_tags( $new_instance['name'] ) ) : '';
			$instance['job']  			= isset( $new_instance['job'] ) ? trim( strip_tags( $new_instance['job'] ) ) : '';
			$instance['description']	= wp_kses_post( $new_instance['description'] );
			$instance['wpautop']     	= ! empty( $new_instance['wpautop'] ) ? 'on' : '';
			$instance['style']   		= strip_tags( $new_instance['style'] );
			$instance['textalign']   	= strip_tags( $new_instance['textalign'] );
			$instance['image']       	= strip_tags( $new_instance['image'] );

			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('About Widget', 'Name', $instance['name']);
				icl_register_string('About Widget', 'Job Name', $instance['job']);
				icl_register_string('About Widget', 'Description', $instance['description']);
				
			} // icl_register_string
				
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( $instance, array(
				'title'         => '',
				'description'	=> '',
				'name'     		=> '',
				'job'     		=> '',
				'wpautop'     	=> '',
				'style'         => 'dtr-about-widget-circle',
				'textalign' 	=> '',
				'image'       	=> '',
			) ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'busybella' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>">
		<?php esc_html_e( 'Name', 'busybella' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'name' ) ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'job' ) ); ?>">
		<?php esc_html_e( 'Job Name', 'busybella' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'job' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'job' ) ); ?>" type="text" value="<?php echo esc_attr( $job ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>">
		<?php esc_attr_e( 'Description', 'busybella' ); ?>
	</label>
	<textarea class="widefat" rows="6" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>"><?php if ( ! empty( $instance['description'] ) ) {  echo wp_kses_post( $instance['description'] ); } ?>
</textarea>
</p>
<p>
	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'wpautop' ) ); ?>" type="checkbox" <?php checked( 'on', $wpautop, true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>">
		<?php esc_html_e( 'Automatically add paragraphs', 'busybella' ); ?>
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>">
		<?php esc_html_e( 'Image Style', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>" class="widefat">
		<option value="dtr-about-widget-circle" <?php selected( $style, 'dtr-about-widget-circle' ) ?>>
		<?php esc_html_e( 'Circle', 'busybella' ); ?>
		</option>
		<option value="dtr-about-widget-square" <?php selected( $style, 'dtr-about-widget-square' ) ?>>
		<?php esc_html_e( 'Default', 'busybella' ); ?>
		</option>
	</select>
</p>
<p style="background: #f2f2f2; padding:10px; font-size: 11px;">
	<?php esc_html_e( 'Provide equal width - height image', 'busybella' ); ?>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'textalign' ) ); ?>">
		<?php esc_html_e( 'Text align', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'textalign' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'textalign' ) ); ?>" class="widefat">
		<option value="text-center" <?php selected( $textalign, 'text-center' ) ?>>
		<?php esc_html_e( 'Default - Center', 'busybella' ); ?>
		</option>
		<option value="text-left" <?php selected( $textalign, 'text-left' ) ?>>
		<?php esc_html_e( 'Left', 'busybella' ); ?>
		</option>
		<option value="text-right" <?php selected( $textalign, 'text-right' ) ?>>
		<?php esc_html_e( 'Right', 'busybella' ); ?>
		</option>
	</select>
</p>

<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>">
			<?php esc_html_e( 'Image URL', 'busybella' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" type="text" value="<?php echo esc_attr( $image ); ?>" />
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'BUSYBELLA_About_Widget' );