<?php
/**
 * The Page header for archives
 */

// Page header hook
function busybella_page_header_hook() {
	do_action( 'busybella_page_header_hook' );
}
add_action( 'busybella_page_header_hook', 'busybella_default_page_header_hook' );

if( ! function_exists( 'busybella_default_page_header_hook' ) ) {
	function busybella_default_page_header_hook() {
		busybella_page_header();
	}
}

// Build Page Title
if ( ! function_exists('busybella_page_title') ) {
	function busybella_page_title( $page_title='' ) {
		
		// Archives   
		if ( is_archive() ) {
			// category
			if ( is_category() ) {
				$page_title = sprintf( single_cat_title( '', false ) );
			// tag
			} elseif ( is_tag() ) {
        		$page_title = sprintf( single_tag_title( '', false ) );
			// Daily archive
			} elseif ( is_day() ) {
				$page_title = sprintf( get_the_date() );
			// Monthly archive
			} elseif ( is_month() ) {
				$page_title = sprintf( get_the_date( _x( 'F Y', 'monthly archives date format', 'busybella' ) ) );	
			// Yearly archive
			} elseif ( is_year() ) {
				$page_title = sprintf( get_the_date( _x( 'Y', 'yearly archives date format', 'busybella' ) ) );	
			//Author
			} elseif ( is_author() ) { 
         		$page_title = sprintf( get_the_author() );
			// Standard title
			} else {
				$page_title = single_term_title("", false);
				if ( $page_title == '' ) {
					$post_id = get_the_ID();
					$page_title = get_the_title( $post_id );
				}
			}
		// Search
		} elseif( is_search() ) {
			$page_title =  sprintf( esc_html__( ' Search Results : %s', 'busybella' ), get_search_query() );   
		// else
		} else {
			$post_id = get_the_ID();
			$page_title = get_the_title( $post_id );
		}
		return esc_attr( $page_title );
	} 
} 

// Page Header output
if ( ! function_exists( 'busybella_page_header' ) ) {
	function busybella_page_header() {
		global $post;
		$page_title	= busybella_page_title();
		
		// Return if WooCommerce
		if ( function_exists('is_woocommerce') ) {
			if ( is_woocommerce() && !is_singular( 'page' ) ) return;
		}
		
		if ( is_front_page()|| is_home()|| is_page() || is_single()  ) return;
		if ( 'hide' == get_theme_mod( 'busybella_archive_title_enable', 'show' )  ) return;
		
?>
<div id="dtr-page-title-wrapper">
<div class="dtr-container">
	<?php if ( 'show' == get_theme_mod( 'busybella_archive_heading_enable', 'show' ) ) { 	 ?>
	<h1 class="dtr-page-title entry-title" <?php busybella_schema_markup( 'headline' ); ?>> <?php echo esc_attr( $page_title ); ?> </h1>
	<?php }  ?>
	<?php if ( 'show' == get_theme_mod( 'busybella_archive_breadcrumb_enable', 'show' ) ) { 	 ?>
	<?php get_template_part( '/template-parts/header/breadcrumb' ); ?>
	<?php }  ?>
</div>
</div>
<?php	
    } 
}