<?php
/*------------------------------------------------------------
 * Table of Contents
 *
 * Vertical Spacer / Gap
 * Horizontal Spacer / Gap
 * Separator
 * Dropcap	
 * Highlight
 * Text Style
 * Tooltip
 * Lists
 * Video Wrapper
 * Testimonial
 * Testimonial Carousel
 * Recent Posts Carousel
 *------------------------------------------------------------*/

/*------------------------------------------------------------
 * Remove extra P tags
 *------------------------------------------------------------*/
add_filter("the_content", "busybella_shortcode_format");
function busybella_shortcode_format($content) {
	// array of custom shortcodes requiring the fix
	$block = join("|",array( "dtr_spacer","dtr_spacer_wide","dtr_separator","dtr_dropcap","dtr_highlight","dtr_text_style","dtr_tooltip","list","ordered_list","list_item", "dtr_listicon", "dtr_video_wrapper", "dtr_checkmark_list", "dtr_circle_list", "dtr_star_list", "dtr_heart_list", "dtr_circle_arrow_list", "dtr_arrow_list", "dtr_checkmark_square_list", "dtr_checkmark_circle_list" ) );

	// opening tag
	$rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>)?/","[$2$3]",$content);
	// closing tag
	$rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>)?/","[/$2]",$rep);
	return $rep;
}

/*
 * @param $content
 * @param bool $autop
 * @return string
 */
if ( ! function_exists( 'busybella_remove_wpautop' ) ) {
	function busybella_remove_wpautop( $content, $autop = false ) {
		if ( $autop ) { // Possible to use !preg_match('('.WPBMap::getTagsRegexp().')', $content)
			$content = wpautop( preg_replace( '/<\/?p\>/', "\n", $content ) . "\n" );
		}
		return do_shortcode( shortcode_unautop( $content ) );
	}
}

/*------------------------------------------------------------
 * Vertical Spacer / Gap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_spacer_sc' ) ) {
	function busybella_spacer_sc( $atts, $content ) {
		extract ( shortcode_atts( array(
			'height'	=> '', // in px
		), $atts ) );
		return '<div class="spacer" style="height: ' . esc_attr( $height ) . ';"></div>';
	}
}
add_shortcode( 'dtr_spacer', 'busybella_spacer_sc' );
	
/*------------------------------------------------------------
 * Horizontal Spacer / Gap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_wide_spacer_sc' ) ) {
	function busybella_wide_spacer_sc( $atts, $content ) {
		extract ( shortcode_atts( array(
			'width'       => '', // in px
		), $atts ) );
		return '<span class="spacer-wide" style="width: ' . esc_attr( $width ) . ';"></span>';
	}
}
add_shortcode( 'dtr_spacer_wide', 'busybella_wide_spacer_sc' );

/*------------------------------------------------------------
 * Separator
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_separator_sc' ) ) {
	function busybella_separator_sc( $atts, $content=null ) {
		extract ( shortcode_atts( array(
			'width'			=> '', 
			'color'			=> '', 
			'margin_top'	=> '', 
			'margin_bottom'	=> '', 
			'align'			=> '', 
			'border_style'	=> '', 
			'border_width'	=> '', 
		), $atts ) );
		// align
		if( $align == 'left' ){
			$return_align = ' left-separator';
		} elseif( $align == 'right' ){
			$return_align = ' right-separator';
		} elseif( $align == 'center' ){
			$return_align = '';
		} else {
			$return_align = '';
		}
		// style
		$add_style = array();
		if ( $width ) {
			$add_style[] = 'width: '. $width .';';
		} 
		if ( $border_width ) {
			$add_style[] = 'border-top-width: '. $border_width .';';
		} 
		if ( $border_style ) {
			$add_style[] = 'border-top-style: '. $border_style .';';
		} 
		if ( $color ) {
			$add_style[] = 'border-color: '. $color .';';
		} 
		if ( $margin_top ) {
			$add_style[] = 'margin-top: '. $margin_top .';';
		} 
		if ( $margin_bottom ) {
			$add_style[] = 'margin-bottom: '. $margin_bottom .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<div class="line-separator' . esc_attr( $return_align ) . '"' . $add_style . '></div>';
	}
}
add_shortcode( 'dtr_separator', 'busybella_separator_sc' );

/*------------------------------------------------------------
 * Dropcap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_dropcap_sc' ) ) {
	function busybella_dropcap_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'bgcolor'	=> '', 
			'color'		=> '', 
			'style' 	=> '', // default/circle/square
		), $atts ) );

		$add_style = array();
		if( $bgcolor != ''  ) {
			$add_style[] = 'background-color: '. $bgcolor .';';
		} 
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		return '<span class="dtr-dropcap ' . esc_attr( $style ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</span>';
	}  
}
add_shortcode( 'dtr_dropcap', 'busybella_dropcap_sc' ); 
 
/*------------------------------------------------------------
 * Highlight
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_text_highlight_sc' ) ) {
	function busybella_text_highlight_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'bgcolor' 	=> '', 
		'color'   	=> '', 
		'font_size'	=> '', 
	), $atts ) );
	
	$add_style = array();
	if( $bgcolor != ''  ) {
		$add_style[] = 'background-color: '. $bgcolor .';';
	} 
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	if( $font_size != ''  ) {
		$add_style[] = 'font-size: '. $font_size .';';
	} 
	$add_style = implode('', $add_style);
	
	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '" ';
	}
	return '<span class="dtr-highlight"' . $add_style . '>' . do_shortcode( $content ) . '</span>';
	}
}
add_shortcode( 'dtr_highlight', 'busybella_text_highlight_sc' );

/*------------------------------------------------------------
 * Text style
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_text_style_sc' ) ) {
	function busybella_text_style_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'size' 				=> '', 
			'line_height'		=> '', 
			'color' 			=> '', 
			'font_weight'		=> '', 
			'letter_spacing'	=> '', 
			'class' 			=> '',
			'return_class' 		=> '',
		), $atts ) );
		
		$content = busybella_remove_wpautop($content, true);
		// style
		$add_style = array();
		if ( $size ) {
			$add_style[] = ' font-size: ' . $size . ';';
		} 
		if ( $line_height ) {
			$add_style[] = ' line-height: ' . $line_height . ';';
		} 
		if ( $color ) {
			$add_style[] = ' color: ' . $color . ';';
		} 
		if ( $font_weight ) {
			$add_style[] = ' font-weight: ' . $font_weight . ';';
		} 
		if ( $letter_spacing ) {
			$add_style[] = ' letter-spacing: ' . $letter_spacing . ';';
		} 
		$add_style = implode('', $add_style);
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		
		// class
		if( $class ) {
			$return_class = ' class="'. esc_attr( $class ) .'"';
		} 
		
		return '<div' . $add_style . '' . $return_class . '>' . $content . '</div>';
	}
}
add_shortcode( 'dtr_text_style', 'busybella_text_style_sc' );

/*------------------------------------------------------------
 * Tooltip
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_tooltip_sc' ) ) {
	function busybella_tooltip_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'url'       => '', 
			'title'     => '', 
			'color'     => '', 
			'font_size' => '', 
			'placement'	=> 'top', // top, bottom, left, right
		), $atts ) );
		
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		
		if( $url != ''  ) {
			$return_url = 'href="' . esc_url( $url ) . '" ';
		}
		else{
			$return_url = '';
		}
		return '<a ' . $return_url . 'title="' . esc_attr( $title ) . '" data-placement="' . esc_attr( $placement ) . '" data-toggle="tooltip"' . $add_style . '>' . do_shortcode( $content ) . '</a>';
	}
}
add_shortcode( 'dtr_tooltip', 'busybella_tooltip_sc' );

/*------------------------------------------------------------
 * Lists
 * @since 1.0
 *------------------------------------------------------------*/
// ul
if ( ! function_exists( 'busybella_list_sc' ) ) {
	function busybella_list_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'color'				=> '', 
			'font_size'			=> '', 
			'line_height'		=> '', 
			'list_style'		=> '', 
		), $atts ) );
		
		// add list style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		if( $list_style != ''  ) {
			$add_style[] = 'list-style-type: '. $list_style .';';
		} 
		$add_style = implode('', $add_style);
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<ul class="common-list" ' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
	}
}
add_shortcode( 'dtr_list', 'busybella_list_sc' );

// ol
if ( ! function_exists( 'busybella_ordered_list_sc' ) ) {
	function busybella_ordered_list_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'color'			=> '', 
			'font_size'		=> '', 
			'line_height'	=> '', 
			'list_style'	=> '', 
		), $atts ) );
		
		// add list style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		if( $list_style != ''  ) {
			$add_style[] = 'list-style-type: '. $list_style .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<ol class="list" ' . $add_style . '>' . do_shortcode( $content ) . '</ol>';
	}
}
add_shortcode( 'dtr_ordered_list', 'busybella_ordered_list_sc' );

// Checkmark list
function busybella_checkmark_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_list', 'busybella_checkmark_list_sc' );

// Checkmark circle list
function busybella_checkmark_circle_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_circle_list', 'busybella_checkmark_circle_list_sc' );

// Checkmark square list
function busybella_checkmark_square_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark-square' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_square_list', 'busybella_checkmark_square_list_sc' );

// arrow list
function busybella_arrow_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-arrow' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_arrow_list', 'busybella_arrow_list_sc' );

// circle arrow list
function busybella_circle_arrow_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-arrow-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_circle_arrow_list', 'busybella_circle_arrow_list_sc' );

// heart list
function busybella_heart_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-heart' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_heart_list', 'busybella_heart_list_sc' );

// star list
function busybella_star_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-star' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_star_list', 'busybella_star_list_sc' );

// circle list
function busybella_circle_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_circle_list', 'busybella_circle_list_sc' );

// li
if ( ! function_exists( 'busybella_list_item_sc' ) ) {
	function busybella_list_item_sc( $atts, $content = null ) {
		return '<li>' . do_shortcode( $content ) . '</li>';
	}
}
add_shortcode( 'dtr_list_item', 'busybella_list_item_sc' );


// List with icon
if ( ! function_exists( 'busybella_icon_list_sc' ) ) {
	function busybella_icon_list_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
		'icon_type'   		=> '',
		'color'        		=> '',
		'font_size'        => '',
		'line_height'      => '',
		'icon_color'   		=> '',
		'list_content'      => '', 
		), $atts ) );
		
		// style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
			$add_style[] = 'padding-left: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		// icon style
		$add_style_icon = array();
		if( $icon_color != ''  ) {
			$add_style_icon[] = 'color: '. $icon_color .';';
		} 
		$add_style_icon = implode('', $add_style_icon);
		
		if ( $add_style_icon ) {
			$add_style_icon = wp_kses( $add_style_icon, array() );
			$add_style_icon = ' style="' . esc_attr($add_style_icon) . '"';
		}

		// icon_type
		if( $icon_type ) {
			$return_icon = '<i class="' . esc_attr( $icon_type ) . '"' . $add_style_icon . '></i>';
		} else {
			$return_icon = '';
		}
		
		return '<p class="dtr-list-icon"' . $add_style . '>' . $return_icon . '<span>' . $list_content . '</span></p>';
	}
}
add_shortcode( 'dtr_listicon', 'busybella_icon_list_sc' );

/*------------------------------------------------------------
 * Video Wrapper
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_video_wrapper_sc' ) ) {
	function busybella_video_wrapper_sc( $atts, $content = null ) {
		return '<div class="dtr-video-wrapper">' . do_shortcode( $content ) . '</div>';
	}
}
add_shortcode( 'dtr_video_wrapper', 'busybella_video_wrapper_sc' );

/*------------------------------------------------------------
 * Testimonial
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_testimonial_sc' ) ) {
	function busybella_testimonial_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'id'  					=> '',
		), $atts ) );
	
		global $post;
		$args = array(
			'name'           	=> esc_attr( $id ),
			'post_type'      	=> 'dtr_testimonial',
			'post_status'    	=> 'publish',
		);
		$output = '';
		$query = new WP_Query( $args );
		if ($query->have_posts()) :	
		$output .= '<div class="dtr-testimonial dtr-testimonial-style1">';
			while ( $query->have_posts() ) : $query->the_post();
				$output .= '<div class="dtr-testimonial-item item clearfix">';
				$thumb       			= get_post_thumbnail_id(); 
				$img_url     			= wp_get_attachment_url( $thumb, 'full' ); 
				$image       			= aq_resize( $img_url, 70, 70, true );

				$client_name 			= get_post_meta( $post->ID, '_busybella_testimonial_client_name', true );
				$client_designation 	= get_post_meta( $post->ID, '_busybella_testimonial_client_designation', true );
				// output	
				$output .= '<div class="dtr-testimonial-description">';
				$content = get_the_content();
				$content = apply_filters( 'the_content', $content );
				$content = str_replace( ']]>', ']]&gt;', $content );
				$output .= $content;
				$output .= '</div>';
				if( has_post_thumbnail() || $client_name || $client_designation  ){
					$output .= '<div class="dtr-testimonial-info">';
					if ( has_post_thumbnail() ) {	
						$output .= '<span class="dtr-testimonial-img"><img src="' . esc_url( $image ) . '" alt="' . esc_attr( $client_name ) . '"/></span>';
					}
					if( $client_name || $client_designation  ){
						$output .= '<div class="dtr-testimonial-info-text">';
						if( $client_name ){
							$output .= '<h5 class="dtr-testimonial-client-name">' . esc_attr( $client_name ) . '</h5>';
						} 
						if( $client_designation ){ 
							$output .= '<span class="dtr-testimonial-client-designation">' . esc_attr( $client_designation ) . '</span>';
						} 
						$output .= '</div>';
					}
					$output .= '</div>';
				}
				$output .= '</div>';
			endwhile;
			$output .= '</div>';
			wp_reset_postdata();
		endif;
		return $output;
	}
}
add_shortcode('dtr_testimonial', 'busybella_testimonial_sc');

/*------------------------------------------------------------
 * Testimonial Carousel
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'busybella_testimonial_carousel_sc' ) ) {
	function busybella_testimonial_carousel_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'id'  					=> '',
			'limit'     			=> -1,
			'order'     			=> 'DESC',
			'orderby'   			=> 'date',
		), $atts ) );
	
		global $post;
		$args = array(
			'name'           	=> esc_attr( $id ),
			'post_type'      	=> 'dtr_testimonial',
			'posts_per_page'	=> esc_attr( $limit ),
			'order'          	=> esc_attr( $order ), 
			'orderby'        	=> $orderby,
			'post_status'    	=> 'publish',
		);
		$output = '';
		$query = new WP_Query( $args );
		if ($query->have_posts()) :	
		$output .= '<div class="owl-carousel dtr-owl-theme dtr-testimonial dtr-testimonial-carousel">';
			while ( $query->have_posts() ) : $query->the_post();
				$output .= '<div class="dtr-testimonial-item item clearfix">';
				$thumb       			= get_post_thumbnail_id(); 
				$img_url     			= wp_get_attachment_url( $thumb, 'full' ); 
				$image       			= aq_resize( $img_url, 80, 80, true );
				$client_name 		    = get_post_meta( $post->ID, '_busybella_client_name', true );

				$client_name 			= get_post_meta( $post->ID, '_busybella_testimonial_client_name', true );
				$client_designation 	= get_post_meta( $post->ID, '_busybella_testimonial_client_designation', true );
				
				$output .= '<div class="dtr-testimonial-description">';
				$content = get_the_content();
				$content = apply_filters( 'the_content', $content );
				$content = str_replace( ']]>', ']]&gt;', $content );
				$output .= $content;
				$output .= '</div>';
				$output .= '<div class="dtr-testimonial-info">';
				
				if ( has_post_thumbnail() ) {	
					$output .= '<span class="dtr-testimonial-img"><img src="' . esc_url( $image ) . '" alt="' . esc_attr( $client_name ) . '"/></span>';
				}
				
				if ( ! has_post_thumbnail() ) {	
				$align_class = ' text-center';
				
				} else { $align_class = ' text-left'; }
				$output .= '<div class="dtr-testimonial-info-text' . $align_class . '">';
				
				if( $client_name ){
					$output .= '<h5 class="dtr-testimonial-client-name">' . esc_attr( $client_name ) . '</h5>';
				} 
				if( $client_designation ){ 
					$output .= '<span class="dtr-testimonial-client-designation">' . esc_attr( $client_designation ) . '</span>';
				} 
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
			endwhile;
			$output .= '</div>';
			wp_reset_postdata();
		endif;
		return $output;
	}
}
add_shortcode('dtr_testimonial_carousel', 'busybella_testimonial_carousel_sc');

/*------------------------------------------------------------
 * Recent Posts Carousel
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'dtr_busybella_recentpost_sc' ) ) {
	function dtr_busybella_recentpost_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'title'     	=> '',
			'image'			=> '',
			'excerpt'   	=> '',
			'date'   		=> '',
			'author'   		=> '',
			'pinit'	    	=> '',
			'limit'     	=> -1,
			'order'     	=> 'DESC',
			'orderby'   	=> 'date',
			'cat'	    	=> '',
			'category'		=> '',
			'animation'		=> '', 
			'more_link'		=> '', 
			'more_link_text'	=> '', 
		), $atts ) );
		

		$cat = str_replace(' ','-',$cat);
		 
		global $post;
		$args = array(
			'post_type'      => '',
			'posts_per_page' => esc_attr( $limit ),
			'order'          => esc_attr( $order ), 
			'orderby'        => $orderby,
			'post_status'    => 'publish',
			'category_name'  => $cat, 
		);
	
		query_posts( $args );
		$output = '';
		if( have_posts() ) : 
			$output .= '<div class="owl-carousel dtr-recentpost-carousel dtr-owl-theme">';
			while ( have_posts() ) : the_post();
				$output .= '<div class="item dtr-recentpost-carousel-item clearfix">';
				$permalink		= get_permalink();
				$thumb_title	= get_the_title();	
				$post_id 		= get_the_ID();
				$url      		= get_permalink( $post_id );
				$thumb       	= get_post_thumbnail_id(); 
				$img_url     	= wp_get_attachment_url( $thumb, 'full' ); 
				$image_resize   = aq_resize( $img_url, 400, 300, false );

				// thumbnail
				if( has_post_thumbnail() && $image == 'show' ) { 
					$output .=  '<div class="dtr-post-carousel-img dtr-img-scale"><img src="' . esc_url( $image_resize ) . '" alt="' . esc_attr( $thumb_title ) . '"/>';
					if( $pinit == 'show' ) {
						$output .= '<a href="https://www.pinterest.com/pin/create/button/?url=' .  rawurlencode( esc_url( $url ) ) . '&amp;media=' .  wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ) . '&amp;description=' .  rawurlencode( $thumb_title ) . '" title="" onclick="javascript:window.open(this.href, \'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500\');return false;" class="dtr-pinit-label">' . esc_html__('save','busybella') . '</a>';
					}
					$output .=  '</div>';
				}
				
				if( $title == 'show' || $excerpt  == 'show' || $date == 'show' || $category  == 'show' ) {
				$output .= '<div class="dtr-post-carousel-content">';
				}
				
					// category
					if( $category == 'show' ) {
						$cats = get_the_category( $post->ID );
						if( $cats ) {
							 $output .= '<div class="dtr-meta-category dtr-cat-style">';
						 foreach( $cats as $cat ) {
										$output .= '<a href="' . esc_url( get_category_link( $cat->term_id ) ) . '">'. $cat->name .'</a>';
								}
								 $output .= '</div>';
						}
					}

					// title
					if( $title == 'show' ):
						$output .= '<h5 class="dtr-post-carousel-title"><a href="' . esc_url( $permalink ) . '" rel="bookmark">' . esc_attr(get_the_title()) . '</a></h5>';
					endif;	
					
					if( $date == 'show' || $author == 'show' ) {
						$output .= '<ul class="dtr-meta">';
						// author
						if( $author == 'show' ) {
							$output .= '<li class="dtr-meta-author">' . esc_attr( get_the_author() ) . '</li>';
						}
						// date
						if( $date == 'show' ) {
							$output .= '<li class="dtr-meta-date"><a href="' . esc_url( $permalink ) . '" rel="bookmark">' . esc_attr(get_the_date()) . '</a></li>';
						}
						$output .= '</ul>';
					
					} // date / author

					// excerpt
					if($excerpt == 'show'):	
						$output .= '<div class="dtr-post-carousel-excerpt">';
						$content = get_the_excerpt();
						$content = str_replace( ']]>', ']]&gt;', $content );
						$output .= $content;
						$output .= '</div>';
					endif;	

					// link
					if( $more_link == 'show' ):
						$output .= '<a class="dtr-post-carousel-link" href="' . esc_url( $permalink ) . '" rel="bookmark">' . esc_html__( $more_link_text, 'busybella' ) . '</a>';
					endif;	

					
					
					if( $title == 'show' || $excerpt  == 'show' || $date == 'show' || $category  == 'show' ) {
					$output .= '</div>';
					}
				$output .= '</div>'; // item
			endwhile;
			$output .= '</div>';
			wp_reset_query();
		endif;
		return $output;
	}	
}
add_shortcode('dtr_recentposts', 'dtr_busybella_recentpost_sc');