<?php
/**
 * Fetch Instagram feed
 */
 
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} 
if( ! function_exists('busybella_scrape_instagram' ) ) { 
	function busybella_scrape_instagram( $username , $item_count = 4 ) {
		
		// username
		$username = strtolower( $username );
		$sanitized_username = str_replace( '@', '', $username );
		
		if ( false === ( $instagram = get_transient( 'busybella-instagram-feed-'. $sanitized_username .'-'. $item_count ) ) ) {

			$remote = wp_remote_get( 'http://instagram.com/'. trim( $username ) );
			
			if ( is_wp_error( $remote ) )
			return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'busybella' ) );

			if ( 200 != wp_remote_retrieve_response_code( $remote ) )
			return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'busybella' ) );
			
			$shards = explode( 'window._sharedData = ', $remote['body'] );
			$insta_json = explode( ';</script>', $shards[1] );
			$insta_array = json_decode( $insta_json[0], TRUE );

			if ( ! $insta_array )
			return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );

			if ( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ) {
				$images = $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
			} else {
				return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );
			}
			
			if ( ! is_array( $images ) )
			return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'busybella' ) );

			$instagram = array();
			foreach ( $images as $image ) {
			switch ( substr( $username, 0, 1 ) ) {
				case '#':
					if ( true === $image['node']['is_video'] ) {
						$type = 'video';
					} else {
						$type = 'image';
					}

					$caption = __( 'Instagram Image', 'busybella' );
					if ( ! empty( $image['node']['edge_media_to_caption']['edges'][0]['node']['text'] ) ) {
						$caption = $image['node']['edge_media_to_caption']['edges'][0]['node']['text'];
					}

					$instagram[] = array(
						'description'   => $caption,
						'link'		  	=> trailingslashit( '//instagram.com/p/' . $image['node']['shortcode'] ),
						'time'		  	=> $image['node']['taken_at_timestamp'],
						'comments'	  	=> $image['node']['edge_media_to_comment']['count'],
						'likes'		 	=> $image['node']['edge_liked_by']['count'],
						'thumbnail'	 	=> preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][0]['src'] ),
						'small'			=> preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][2]['src'] ),
						'large'			=> preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][4]['src'] ),
						'original'		=> preg_replace( '/^https?\:/i', '', $image['node']['display_url'] ),
						'type'		  	=> $type,
					);
					break;
				default:
					if ( true === $image['is_video'] ) {
						$type = 'video';
					} else {
						$type = 'image';
					}

					$caption = __( 'Instagram Image', 'busybella' );
					if ( ! empty( $image['caption'] ) ) {
						$caption = $image['caption'];
					}

					$instagram[] = array(
						'description'   => $caption,
						'link'		  	=> trailingslashit( '//instagram.com/p/' . $image['code'] ),
						'time'		  	=> $image['date'],
						'comments'	  	=> $image['comments']['count'],
						'likes'		 	=> $image['likes']['count'],
						'thumbnail'	 	=> preg_replace( '/^https?\:/i', '', $image['thumbnail_resources'][0]['src'] ),
						'small'			=> preg_replace( '/^https?\:/i', '', $image['thumbnail_resources'][2]['src'] ),
						'large'			=> preg_replace( '/^https?\:/i', '', $image['thumbnail_resources'][4]['src'] ),
						'original'		=> preg_replace( '/^https?\:/i', '', $image['display_src'] ),
						'type'		  	=> $type,
					);

					break;
				}

			} // foreach()

			// do not set an empty transient - should help catch private or empty accounts
			if ( ! empty( $instagram ) ) {
				$instagram = serialize( $instagram );
				set_transient( 'busybella-instagram-feed-'.sanitize_title_with_dashes( $username ), $instagram, apply_filters( 'busybella_instagram_cache_time', HOUR_IN_SECONDS*2 ) );
			}

		}
		// Return array
		if ( ! empty( $instagram )  ) {
			if ( ! is_array( $instagram ) && 1 != $instagram ) {
				$instagram = unserialize( $instagram );
			}
			if ( is_array( $instagram ) ) {
				return array_slice( $instagram, 0, $item_count );
			}
		}
		// No images returned
		else {
			return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'busybella' ) );
		}
	}
} //busybella_scrape_instagram