<?php
/**
 * Instagram Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'BUSYBELLA_Instagram_Widget' ) ) {
	class BUSYBELLA_Instagram_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'busybella_instagram_widget',
      			'description' => esc_html__( 'Display Instagram Feed.', 'busybella' )
    		);
    		parent::__construct( 'busybella_instagram_widget', esc_html__( 'Custom: Instagram', 'busybella' ), $widget_ops );
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 	= '';
			$title      = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
			$username	= empty( $instance['username'] ) ? '' : $instance['username'];
			$name   	= empty( $instance['name'] ) ? '' : $instance['name'];
			$number     = empty( $instance['number'] ) ? 5 : $instance['number'];
			$columns    = empty( $instance['columns'] ) ? 'dtr-col-5' : $instance['columns'];
			$gutter     = empty( $instance['gutter'] ) ? 'dtr-col-gap-0px' : $instance['gutter'];	
			$size      	= isset( $instance['size'] ) ? $instance['size'] : 'thumbnail';
			if ( ! in_array( $size, array( 'thumbnail', 'small', 'large', 'original' ) ) ) {
				$size = 'thumbnail';
			}
			$target    	= empty( $instance['target'] ) ? '_self' : $instance['target'];

			// Before widget
			$output .= $args['before_widget'];

			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}
			
			// Instagram content
			// Error notice if no username
			if ( ! $username ) {
				$output .= '<small>' . esc_html__( 'Please provide Instagram username.', 'busybella' ) . '</small>';
			} else {

				// Get instagram images
				$media_array = busybella_scrape_instagram( $username, $number );

				// Display error notice
				if ( is_wp_error( $media_array ) ) {
					echo wp_kses_post( $media_array->get_error_message() );
				}

				// Display instagram feed
				elseif ( is_array( $media_array ) ) {
					
					// Set correct gutter class
					$gutter = $gutter;

					$output .= '<div class="dtr-instagram-widget clearfix">';
						
						$output .= '<ul class="clearfix dtr-col-list dtr-instagram-widget-list ' . esc_attr( $gutter ) . ' ' . esc_attr( $columns ) . '">';
						$count = 0;
						
						foreach ( $media_array as $item ) {
							
							$image = isset( $item['display_src'] ) ? $item['display_src'] : '';
							
							if ( 'thumbnail' == $size ) {
								$image = ! empty( $item['thumbnail_src'] ) ? $item['thumbnail_src'] : $image;
								$image = ! empty( $item['thumbnail'] ) ? $item['thumbnail'] : $image;
							} elseif ( 'small' == $size ) {
								$image = ! empty( $item['small'] ) ? $item['small'] : $image;
							} elseif ( 'large' == $size ) {
								$image = ! empty( $item['large'] ) ? $item['large'] : $image;
							} elseif ( 'original' == $size ) {
								$image = ! empty( $item['original'] ) ? $item['original'] : $image;
							}
							
							if ( $image ) {
								$count++;
								if ( strpos( $item['link'], 'http' ) === false ) {
									$item['link'] = str_replace( '//', 'https://', $item['link'] );
								}
								
								$classes = 'count-'. esc_attr( $count );

								$output .= '<li class="' . $classes . '">';
									$output .= '<a href="' . esc_url( $item['link'] ) . '" title="' . esc_attr( $item['description'] ) . '" target="'. esc_attr( $target ) .'">';
											$output .= '<img src="' . esc_url( $image ) . '"  alt="' . esc_attr( $item['description'] ) . '" />';
										$output .= '</a>';
									$output .= '</li>';

								if ( $columns == $count ) {
									$count = 0;
								}
							}
						}

						$output .= '</ul>';
						
						// link
						if ( $name != '' && $username != '' ) {
							$foliolink = '';
							$foliolink = trailingslashit( '//instagram.com/' . esc_attr( trim( $username ) ) );
							$output .= '<div class="dtr-instagram-title-wrapper clearfix"><a class="dtr-instagram-title" href="' . $foliolink . '" rel="me" target="' . esc_attr( $target ) . '">';
							$output .= wp_kses_post( $name ); 
							$output .= '</a></div>';
						}
						
					$output .= '</div>';
				}

			}
			// instagram content ends 
			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		public function update( $new_instance, $old_instance ) {
			
			$instance               = $old_instance;
			$instance['title']      = strip_tags( $new_instance['title'] );
			$instance['username']	= isset( $new_instance['username'] ) ? trim( strip_tags( $new_instance['username'] ) ) : '';
			$instance['name']  		= isset( $new_instance['name'] ) ? trim( strip_tags( $new_instance['name'] ) ) : '';
			$instance['number']     = ! empty( $new_instance['number'] ) ? intval( $new_instance['number'] ) : 5;
			$instance['columns']    = isset( $new_instance['columns'] ) ? strip_tags( $new_instance['columns'] ) : 'dtr-col-5';
			$instance['gutter']     = isset( $new_instance['gutter'] ) ? strip_tags( $new_instance['gutter'] ) : 'dtr-col-gap-0px';
			$instance['size']   	= isset( $new_instance['size'] ) ? strip_tags( $new_instance['size'] ) : 'thumbnail';
			$instance['target']    	= isset( $new_instance['target'] ) ?  strip_tags( $new_instance['target'] ) : '_self';
			
			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('Instagram Widget', 'Name', $instance['name']);
			} // icl_register_string
			
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( ( array ) $instance, array(
				'title'     => '',
				'username'	=> '',
				'name'     	=> '',
				'number'    => '5',
				'columns'   => 'dtr-col-5',
				'gutter'    => 'dtr-col-gap-0px',
				'size'      => 'thumbnail',
				'target'    => '_self',
			) ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'busybella' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>">
		<?php esc_html_e( 'Username', 'busybella' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'username' ) ); ?>" type="text" value="<?php echo esc_attr( $username ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>">
		<?php esc_html_e( 'Display Name / Username', 'busybella' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'name' ) ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>">
		<?php esc_html_e( 'Number of Photos', 'busybella' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
	</label>
	<small>
	<?php esc_html_e( 'Max 12 photos.', 'busybella' ); ?>
	</small></p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>">
		<?php esc_html_e( 'Nunber of Columns', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>" class="widefat">
		<option value="dtr-col-1" <?php selected( $columns, 'dtr-col-1' ) ?>>
		<?php esc_html_e( 'One', 'busybella' ); ?>
		</option>
		<option value="dtr-col-2" <?php selected( $columns, 'dtr-col-2' ) ?>>
		<?php esc_html_e( 'Two', 'busybella' ); ?>
		</option>
		<option value="dtr-col-3" <?php selected( $columns, 'dtr-col-3' ) ?>>
		<?php esc_html_e( 'Three', 'busybella' ); ?>
		</option>
		<option value="dtr-col-4" <?php selected( $columns, 'dtr-col-4' ) ?>>
		<?php esc_html_e( 'Four', 'busybella' ); ?>
		</option>
		<option value="dtr-col-5" <?php selected( $columns, 'dtr-col-5' ) ?>>
		<?php esc_html_e( 'Five', 'busybella' ); ?>
		</option>
		<option value="dtr-col-6" <?php selected( $columns, 'dtr-col-6' ) ?>>
		<?php esc_html_e( 'Six', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'gutter' ) ); ?>">
		<?php esc_html_e( 'Gap between Photos', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'gutter' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gutter' ) ); ?>" class="widefat">
		<option value="dtr-col-gap-0px" <?php selected( $gutter, 'dtr-col-gap-0px' ) ?>>
		<?php esc_html_e( '0', 'busybella' ); ?>
		</option>
		<option value="dtr-col-gap-6px" <?php selected( $gutter, 'dtr-col-gap-6px' ) ?>>
		<?php esc_html_e( '6px', 'busybella' ); ?>
		</option>
		<option value="dtr-col-gap-10px" <?php selected( $gutter, 'dtr-col-gap-10px' ) ?>>
		<?php esc_html_e( '10px', 'busybella' ); ?>
		</option>
		<option value="dtr-col-gap-20px" <?php selected( $gutter, 'dtr-col-gap-20px' ) ?>>
		<?php esc_html_e( '20px', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>">
		<?php esc_html_e( 'Image Size', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'size' ) ); ?>" class="widefat">
		<option value="thumbnail" <?php selected( $size, 'thumbnail' ) ?>>
		<?php esc_html_e( 'Thumbnail', 'busybella' ); ?>
		</option>
		<option value="small" <?php selected( $size, 'small' ) ?>>
		<?php esc_html_e( 'Small', 'busybella' ); ?>
		</option>
		<option value="large" <?php selected( $size, 'large' ) ?>>
		<?php esc_html_e( 'Large', 'busybella' ); ?>
		</option>
		<option value="original" <?php selected( $size, 'original' ) ?>>
		<?php esc_html_e( 'Original', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>">
		<?php esc_html_e( 'Open links in', 'busybella' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'target' ) ); ?>" class="widefat">
		<option value="_self" <?php selected( '_self', $target ) ?>>
		<?php esc_html_e( 'Current window', 'busybella' ); ?>
		</option>
		<option value="_blank" <?php selected( '_blank', $target ) ?>>
		<?php esc_html_e( 'New window', 'busybella' ); ?>
		</option>
	</select>
</p>
<p style="background: #f2f2f2; padding:10px; font-size: 11px;">
	<?php esc_html_e( 'The Instagram feed is refreshed every 2 hours.', 'busybella' ); ?>
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'BUSYBELLA_Instagram_Widget' );