<?php
/**
 * Social network widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'BUSYBELLA_Social_Widget' ) ) {
	class BUSYBELLA_Social_Widget extends WP_Widget {

		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'busybella_social_widget',
      			'description' => esc_html__( 'Display social icons.', 'busybella' ),
    		);
    		parent::__construct( 'busybella_social_widget', esc_html__( 'Custom: Social Network', 'busybella' ), $widget_ops );
		}
		
		/**
		 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// Get social networks
			$social_networks = isset( $instance['social_networks'] ) ? $instance['social_networks'] : '';
			// return if null
			if ( ! $social_networks ) {
				return;
			}

			// vars
			$output = '';
			$title 	= isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
			$style	= isset( $instance['style'] ) ? $instance['style'] : 'dtr-social-default';
			$align  = isset( $instance['align'] ) ? $instance['align'] : 'left';
			$target = isset( $instance['target'] ) ? $instance['target'] : 'blank';
			$target = 'blank' == $target ? ' target="_blank"' : '';

			// Before widget
			$output .= $args['before_widget'];

			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}
			
			$output .= '<div class="dtr-social-widget clearfix '. esc_attr( $style ) .' text-'. esc_attr( $align ) .'">';
			$output .= '<ul class="dtr-social-list">';
				foreach( $social_networks as $key => $network ) {

					$url = ! empty( $network['url'] ) ? esc_url( $network['url'] ) : '';
					$name = $network['name'];

					if ( $url ) {
						$output .= '<li>';
							$output .= '<a class="dtr-'. strtolower ( esc_attr( $name ) ) .'" href="'. esc_url( $url ) .'" title="'. esc_attr( $name ) .'" '. $target .' rel="nofollow"></a>';
						$output .= '</li>';
					}

				}
			$output .= '</ul>';
			$output .= '</div>'; // .dtr-social-widget
				
			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;

		}

		/**
		 *  Update the information in the WordPress database
		 */	
		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['social_networks'] = $new_instance['social_networks'];
			$instance['title']           = ! empty( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : null;
			$instance['style']           = ! empty( $new_instance['style'] ) ? strip_tags( $new_instance['style'] ) : 'dtr-social-default';
			$instance['align']           = ! empty( $new_instance['align'] ) ? strip_tags( $new_instance['align'] ) : 'left';
			$instance['target']          = ! empty( $new_instance['target'] ) ? strip_tags( $new_instance['target'] ) : 'blank';
			return $instance;
		}

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			$defaults =  array(
			'title'           		=> '',
				'style'           	=> 'dtr-social-default',
				'target'          	=> 'blank',
				'align'           	=> 'left',
				'social_networks'	=> array(
					'facebook'	=> array(
						'name' 	=> 'Facebook',
						'url'  	=> '',
					),
						'twitter'	=> array(
						'name' 		=> 'Twitter',
						'url'  		=> '',
					),
					'instagram'	=> array(
						'name' 	=> 'Instagram',
						'url'  	=> '',
					),
					'pinterest'	=> array(
						'name' 	=> 'Pinterest',
						'url'  	=> '',
					),
					'googleplus'	=> array(
						'name' 		=> 'GooglePlus',
						'url'  		=> '',
					),
					'linkedin'	=> array(
						'name' 	=> 'LinkedIn',
						'url'  	=> '',
					),
					'behance'	=> array(
						'name' 	=> 'Behance',
						'url'  	=> '',
					),
					'medium'	=> array(
						'name' 	=> 'Medium',
						'url'  	=> '',
					),
					'reddit'	=> array(
						'name' 	=> 'Reddit',
						'url'  	=> '',
					),
					'skype'		=> array(
						'name'	=> 'Skype',
						'url'  	=> '',
					),
					'vimeo' 	=> array(
						'name'	=> 'Vimeo',
						'url'  	=> '',
					),
					'mail' 		=> array(
						'name' => 'Mail',
						'url'  => '',
					),
					'yahoo' 	=> array(
						'name'	=> 'Yahoo',
						'url' 	=> '',
					),
					'flickr' 	=> array(
						'name'	=> 'Flickr',
						'url'  	=> '',
					),
					'youtube' 	=> array(
						'name'	=> 'Youtube',
						'url'  	=> '',
					),
					'rss' 		=> array(
						'name'	=> 'RSS',
						'url'  	=> '',
					),
					'dribbble'	=> array(
						'name' 	=> 'Dribbble',
						'url'  	=> '',
					),
					'tumblr'	=> array(
						'name' 	=> 'Tumblr',
						'url'  	=> '',
					),
					'soundcloud'	=> array(
						'name' 		=> 'Soundcloud',
						'url'  		=> '',
					),
					'forumbee'	=> array(
						'name' 	=> 'Forumbee',
						'url'  	=> '',
					),
					'quora'		=> array(
						'name'	=> 'Quora',
						'url'  	=> '',
					),
					'snapchat'	=> array(
						'name' 	=> 'Snapchat',
						'url'  	=> '',
					),
					'digg' 		=> array(
						'name'	=> 'Digg',
						'url'  	=> '',
					),
					'delicious'	=> array(
						'name' 	=> 'Delicious',
						'url'  	=> '',
					),
					'stumbleupon'	=> array(
						'name' 		=> 'Stumbleupon',
						'url'  		=> '',
					),
					'deviantart'	=> array(
						'name' 		=> 'Deviantart',
						'url'  		=> '',
					),
					'yelp' 		=> array(
						'name'	=> 'Yelp',
						'url'  	=> '',
					),
					'viadeo' 	=> array(
						'name'	=> 'Viadeo',
						'url'  	=> '',
					),
					'foursquare'	=> array(
						'name' 		=> 'Foursquare',
						'url'  		=> '',
					),
					'xing' 		=> array(
						'name'	=> 'Xing',
						'url'  	=> '',
					),
					'vk' 		=> array(
						'name'	=> 'VK',
						'url'  	=> '',
					),
					'spotify'	=> array(
						'name' 	=> 'Spotify',
						'url'  	=> '',
					),
					'scribd' 	=> array(
						'name'	=> 'Scribd',
						'url'  	=> '',
					),
					'vine' 		=> array(
						'name'	=> 'Vine',
						'url'  	=> '',
					),
					'fivehrpx'	=> array(
						'name' 	=> 'Fivehrpx',
						'url'  	=> '',
					),
					'slack' 	=> array(
						'name'	=> 'Slack',
						'url'  	=> '',
					),
					'etsy' 		=> array(
						'name'	=> 'Etsy',
						'url'  	=> '',
					),
					'github'	=> array(
						'name' 	=> 'GitHub',
						'url'  	=> '',
					),
				),
			);
			
			$instance = wp_parse_args( ( array ) $instance, $defaults ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'busybella' ); ?>
		:</label>
	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr($this->get_field_id('target')); ?>">
		<?php esc_html_e( 'Open link in :', 'busybella' ); ?>
	</label>
	<select class="widefat" name="<?php echo esc_attr($this->get_field_name('target')); ?>" id="<?php echo esc_attr($this->get_field_id('target')); ?>">
		<option value="blank" <?php selected( $instance[ 'target'], 'blank' ) ?>>
		<?php esc_html_e( 'New Window', 'busybella' ); ?>
		</option>
		<option value="self" <?php selected( $instance[ 'target'], 'self' ) ?>>
		<?php esc_html_e( 'Self', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>">
		<?php esc_attr_e( 'Align', 'busybella' ); ?>
		:</label>
	<br />
	<select name="<?php echo esc_attr( $this->get_field_name( 'align' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>">
		<option value="left" <?php selected( $instance['align'], 'left' ); ?>>
		<?php esc_attr_e( 'Left', 'busybella' ); ?>
		</option>
		<option value="center" <?php selected( $instance['align'], 'center' ); ?>>
		<?php esc_attr_e( 'Center', 'busybella' ); ?>
		</option>
		<option value="right" <?php selected( $instance['align'], 'right' ); ?>>
		<?php esc_attr_e( 'Right', 'busybella' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr($this->get_field_id('style')); ?>">
		<?php esc_html_e( 'Style :', 'busybella' ); ?>
	</label>
	<select class="widefat" name="<?php echo esc_attr($this->get_field_name('style')); ?>" id="<?php echo esc_attr($this->get_field_id('style')); ?>">
		<option value="dtr-social-default" <?php selected($instance[ 'style'], 'dtr-social-default'); ?>>
		<?php esc_html_e( 'Default', 'busybella' ); ?>
		</option>
		<option value="dtr-social-large" <?php selected($instance[ 'style'], 'dtr-social-large'); ?>>
		<?php esc_html_e( 'Large Size Icons', 'busybella' ); ?>
		<option value="dtr-social-circle" <?php selected($instance[ 'style'], 'dtr-social-circle'); ?>>
		<?php esc_html_e( 'Circle', 'busybella' ); ?>
		</option>
		<option value="dtr-social-square" <?php selected($instance[ 'style'], 'dtr-social-square'); ?>>
		<?php esc_html_e( 'Square', 'busybella' ); ?>
		</option>
	</select>
</p>
<?php 	// field names and id
		$networks_field_id   = $this->get_field_id( 'social_networks' );
		$networks_field_name = $this->get_field_name( 'social_networks' ); ?>
<h3 style="margin-top:20px;margin-bottom:0;">
	<?php esc_attr_e( 'Social Links', 'busybella' ); ?>
</h3>
<ul id="<?php echo esc_attr( $networks_field_id ); ?>">
	<input type="hidden" id="<?php echo esc_attr( $networks_field_name ); ?>" value="<?php echo esc_attr( $networks_field_name ); ?>">
	<?php
				$social_networks_show = isset ( $instance['social_networks'] ) ? $instance['social_networks']: '';
				if ( ! empty( $social_networks_show ) ) {
					foreach( $social_networks_show as $key => $network ) {
						$url  = isset( $network['url'] ) ? $network['url'] : 0;
						$name = isset( $network['name'] )  ? $network['name'] : ''; ?>
	<li id="<?php echo esc_attr( $networks_field_id ); ?>_0<?php echo esc_attr( $key ); ?>">
		<p>
			<label for="<?php echo esc_attr( $networks_field_id ); ?>-<?php echo esc_attr( $key ); ?>-name"><?php echo strip_tags( $name ); ?>:</label>
			<input type="hidden" id="<?php echo esc_attr( $networks_field_id ); ?>-<?php echo esc_attr( $key ); ?>-url" name="<?php echo esc_attr( $networks_field_name .'['.$key.'][name]' ); ?>" value="<?php echo esc_attr( $name ); ?>">
			<input type="url" class="widefat" id="<?php echo esc_attr( $networks_field_id ); ?>-<?php echo esc_attr( $key ); ?>-url" name="<?php echo esc_attr( $networks_field_name .'['.$key.'][url]' ); ?>" value="<?php echo esc_attr( $url ); ?>" />
		</p>
	</li>
	<?php }
				} ?>
</ul>
<?php
		}
// class ends
	}
}
register_widget( 'BUSYBELLA_Social_Widget' );