<?php
namespace BusybellaAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Praise Widget
 */
class Busybella_Praise extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'praise';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Praise', 'busybella' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_praise_image',
			[
				'label' => __( 'Praise Image', 'busybella' ),
			]
		);
		
		$this->add_control(
			'praise_image_align',
			[
				'label' => __( 'Image Alignment', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-praise-left-img',
				'label_block' => true,
				'show_label' => true,
				'options' => [
					'dtr-praise-left-img'	=> __( 'Left', 'busybella' ),
					'dtr-praise-right-img'	=> __( 'Right', 'busybella' ),
				],
			]
		);
		
		$this->add_control(
			'praise_image',
			[
				'label' => __( 'Choose Image', 'busybella' ),
				'type' => Controls_Manager::MEDIA,
					'selectors' => [
				'{{WRAPPER}} div.dtr-praise-img, {{WRAPPER}} .dtr-praise-img' => 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'praise_image_position',
			[
				'label' => __( 'Background Position', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'top left' => _x( 'Top Left', 'Background Control', 'busybella' ),
				'top center' => _x( 'Top Center', 'Background Control', 'busybella' ),
				'top right' => _x( 'Top Right', 'Background Control', 'busybella' ),
				'center left' => _x( 'Center Left', 'Background Control', 'busybella' ),
				'center center' => _x( 'Center Center', 'Background Control', 'busybella' ),
				'center right' => _x( 'Center Right', 'Background Control', 'busybella' ),
				'bottom left' => _x( 'Bottom Left', 'Background Control', 'busybella' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'busybella' ),
				'bottom right' => _x( 'Bottom Right', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-praise-img, {{WRAPPER}} .dtr-praise-img' => 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'praise_image_repeat',
			[
				'label' => __( 'Background Repeat', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'no-repeat' => _x( 'No-repeat', 'Background Control', 'busybella' ),
				'repeat' => _x( 'Repeat', 'Background Control', 'busybella' ),
				'repeat-x' => _x( 'Repeat-x', 'Background Control', 'busybella' ),
				'repeat-y' => _x( 'Repeat-y', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-praise-img, {{WRAPPER}} .dtr-praise-img' => 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'praise_image_size',
			[
				'label' => __( 'Background Repeat', 'busybella' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'busybella' ),
				'auto' => _x( 'Auto', 'Background Control', 'busybella' ),
				'cover' => _x( 'Cover', 'Background Control', 'busybella' ),
				'contain' => _x( 'Contain', 'Background Control', 'busybella' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-praise-img, {{WRAPPER}} .dtr-praise-img' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// image control ends
		
		// content control starts
		$this->start_controls_section(
			'section_praise_content',
			[
				'label' => __( 'Praise Content', 'busybella' ),
			]
		);

	
		// title
		$this->add_control(
			'praise_title',
			[
				'label' => __( 'Title Text', 'busybella' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Title Here', 'busybella' ),
				'placeholder' => __( 'Your Title', 'busybella' ),
				'label_block' => true,
			]
		);
		
		// subtitle
		$this->add_control(
			'praise_subtitle',
			[
				'label' => __( 'Subtitle Text', 'busybella' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Subtitle Here', 'busybella' ),
				'placeholder' => __( 'Your Subtitle', 'busybella' ),
				'label_block' => true,
			]
		);
		
		// description
		$this->add_control(
			'praise_description_text',
			[
				'name' => 'tab_content',
				'label' => __( 'Content', 'busybella' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Praise Text Here', 'busybella' ),
				'show_label' => true,
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'busybella' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'praise_text_bg_color',
			[
				'label' => __( 'Text Background Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-praise-description-wrapper, {{WRAPPER}} .dtr-praise-description-wrapper' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'praise_content_color',
			[
				'label' => __( 'Content Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-praise-description, {{WRAPPER}} .dtr-praise-description' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'praise_title_color',
			[
				'label' => __( 'Title Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-praise-title' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'praise_subtitle_color',
			[
				'label' => __( 'Sub Title Color', 'busybella' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-praise-subtitle' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		$html .= '<div class="dtr-praise clearfix ' . $settings['praise_image_align'] . '">';
			$html .= '<div class="dtr-praise-img"></div>';
			$html .= '<div class="dtr-praise-description-wrapper">';
				if ( ! empty( $settings['praise_title'] ) || ! empty( $settings['praise_subtitle'] ) ) { 
				$html .= '<div class="dtr-praise-info">';
				if ( ! empty( $settings['praise_title'] ) ) { 
					$html .= sprintf( '<h5 class="dtr-praise-title">%s</h5>', $settings['praise_title'] );
				}
				if ( ! empty( $settings['praise_subtitle'] ) ) { 	
					$html .= sprintf( '<span class="dtr-praise-subtitle">%s</span>', $settings['praise_subtitle'] );
		
				}  
				$html .= '</div>';
				}
				if ( ! empty( $settings['praise_description_text'] ) ) {
				$html .= '<div class="dtr-praise-description">';
					$html .= sprintf( '%s', $settings['praise_description_text'] );
				$html .= '</div>';
				}
			$html .= '</div>';
		$html .= '</div>';
		echo $html;	
	}
	
	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		var html = '<div class="dtr-praise clearfix ' + settings.praise_image_align + '">';
		html += '<div class="dtr-praise-img"></div>';
		html += '<div class="dtr-praise-description-wrapper">';
		html += '<div class="dtr-praise-info">';
		if ( settings.praise_title ) {
			html += '<h5 class="dtr-praise-title">' + settings.praise_title + '</h5>';
		}
		if ( settings.praise_subtitle ) {
			html += '<span class="dtr-praise-subtitle">' + settings.praise_subtitle + '</span>';
		}
		html += '</div>';	
		html += '<div class="dtr-praise-description">';
		if ( settings.praise_description_text ) {
			html += '' + settings.praise_description_text + '';
		}
		html += '</div>';
		html += '</div></div>';
		print( html );
		#>
		<?php
	}
}